package VMOMI::HostGraphicsConfigGraphicsType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
